@@ -54,9 +54,10 @@ class Youtube:
         screen_size: Optional[Tuple[int, int]] = None,
         full_screen: bool = False,
         disable_images: bool = False,
+        user_agent: Optional[str] = None,
         login_prompt_callback: Optional[Callable[[str], None]] = None
     ):
-        self.browser = Firefox(cookies_folder_path, extensions_folder_path, host=host, port=port, screen_size=screen_size, full_screen=full_screen, disable_images=disable_images)
+        self.browser = Firefox(cookies_folder_path, extensions_folder_path, host=host, port=port, screen_size=screen_size, user_agent=user_agent, full_screen=full_screen, disable_images=disable_images)
         self.channel_id = None
 
         try:
@@ -262,9 +263,9 @@ class Youtube:
             start_time = time.time()
 
             while True:
-                endscreen_editor_overlay = self.browser.find_by('div', class_='uploading-overlay style-scope ytcp-video-info')
+                attrs = self.browser.get_attributes(self.browser.find_by('ytcp-text-dropdown-trigger', id_='endscreen-editor-link'))
 
-                if endscreen_editor_overlay and endscreen_editor_overlay.text and 'processing' in endscreen_editor_overlay.text.lower():
+                if not attrs or 'disabled' in attrs:
                     if time.time() - start_time < max_wait_seconds_for_processing:
                         time.sleep(1)
 
@@ -276,18 +277,13 @@ class Youtube:
 
             self.browser.find_by('ytcp-text-dropdown-trigger', id_='endscreen-editor-link').click()
             time.sleep(0.5)
-            end_screen_elements = self.browser.find_all_by('div', class_='card style-scope ytve-endscreen-template-picker')
-
-            for end_screen_element in end_screen_elements:
-                end_screen_element.click()
-                time.sleep(0.5)
-                self.browser.find_by('ytcp-button', id_='save-button').click()
-
-                break
-
+            self.browser.find_all_by('div', class_='card style-scope ytve-endscreen-template-picker')[0].click()
             time.sleep(0.5)
+            self.browser.find_by('ytcp-button', id_='save-button').click()
 
-            return self.browser.find_by('div', class_='element-header style-scope ytve-endscreen-editor-options-panel', timeout=2.5) is None
+            time.sleep(2)
+
+            return self.browser.find_by('ytve-endscreen-editor-options-panel', class_='style-scope ytve-editor', timeout=0.5) is None
         except Exception as e:
             print(e)
 
@@ -395,7 +391,7 @@ class Youtube:
                         timeout=0.2
                     )
 
-                    upload_status = UploadStatus.get_status(upload_progress_element)
+                    upload_status = UploadStatus.get_status(self.browser, upload_progress_element)
 
                     if upload_status in [UploadStatus.PROCESSING_SD, UploadStatus.PROCESSED_SD_PROCESSING_HD, UploadStatus.PROCESSED_ALL]:
                         done_button = self.browser.find(By.ID, 'done-button')
